===========================
AllSpeak
===========================

.. image:: https://travis-ci.org/lucuma/allspeak.svg?branch=master
   :target: https://travis-ci.org/lucuma/Allspeak
   :alt: Build Status

AllSpeak is a pythonic (yet ironically inspired by Rails) i18n/l10n solution for humans. It's flexible, easy to use and —unlike gettext— independent of any external compilation tool.

-----

How can the translator of your multi-language web application update a text? Compiling `.po` files for a web app, really? How the Rails community solved that problem? Translations in `yaml` or `json` files. With Python it should be that simple. **Now it is**.

And the files used by Allspeak are compatible with those of Rails, so you can use any third-party service already compatible with them (for example, `Transifex <https://www.transifex.com/>`_).

Powered by Babel and pytz libraries.

Read the documentation here: http://allspeak.lucuma.co


What's in a name?
----------------------------------------------

    "When Thor speaks with the All-Speak anyone who hears him will hear him speak their native language in their hearts" ——(from Thor's wiki page)


-----

:copyright: 2012-2015 by `Juan-Pablo Scaletti <http://jpscaletti.com>`_.
:license: MIT, see LICENSE for more details.
